assert( Assister, "Assister not found!")

Assister_MoveTooltip = Assister:NewModule("MoveTooltip")

function Assister_MoveTooltip:OnInitialize()
settingsMoveTooltip = Assister:AcquireDBNamespace("MoveTooltip")
Assister:RegisterDefaults("MoveTooltip", "profile", {
			["on"] = true,
})
Assister.Menu.args.MT = {
			type ="group",
			name = "MoveTooltip",
			desc = "MoveTooltip Config",
			args = {
			Anchor = {
                type = "toggle",
                name = "Anchor",
                desc = "Toggles weather the anchor is shown.",
                get = function() return self.frames.anchor:IsShown() end,
                set = function() if self.frames.anchor:IsShown() then self.frames.anchor:Hide() else self.frames.anchor:Show() end end,
            },
			Toggle = {
                type = "toggle",
                name = "Toggle",
                desc = "Toggle the module on and off.",
                get = function() return Assister:IsModuleActive("Resurect") end,
                set = function(v) settingsMoveTooltip.profile.on=Assister:ToggleModuleActive("Resurect") end,
            },
},
}
end

--Fired on Mod Enable
function Assister_MoveTooltip:OnEnable()
	settingsMoveTooltip.profile.on = true
	Assister_MoveTooltip:SetupFrames()
	Assister_MoveTooltip:Move()
end

--Fired on Mod Standby
function Assister_MoveTooltip:OnDisable()
Assister:Print("tet")
	settingsMoveTooltip.profile.on = false
	Assister_MoveTooltip:Move()
end

--Frames, thanks BigWigs writers!
 
 function Assister_MoveTooltip:SetupFrames()
	local f, t

	f, _, _ = GameFontNormal:GetFont()

	self.frames = {}
	self.frames.anchor = CreateFrame("Frame", "AssisterMTAnchor", UIParent)
	self.frames.anchor.owner = self
	self.frames.anchor:Hide()

	self.frames.anchor:SetWidth(60)
	self.frames.anchor:SetHeight(40)
	self.frames.anchor:SetBackdrop({
		bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background", tile = true, tileSize = 16,
		edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border", edgeSize = 16,
		insets = {left = 4, right = 4, top = 4, bottom = 4},
		})
	self.frames.anchor:SetBackdropBorderColor(.5, .5, .5)
	self.frames.anchor:SetBackdropColor(0,0,0)
	self.frames.anchor:ClearAllPoints()
	self.frames.anchor:SetPoint("CENTER", UIParent, "CENTER", 0, 0)
	self.frames.anchor:EnableMouse(true)
	self.frames.anchor:RegisterForDrag("LeftButton")
	self.frames.anchor:SetMovable(true)
	self.frames.anchor:SetScript("OnDragStart", function() this:StartMoving() end)
	self.frames.anchor:SetScript("OnDragStop", function() this:StopMovingOrSizing() this.owner:SavePosition() end)

	self.frames.cfade = self.frames.anchor:CreateTexture(nil, "BORDER")
	self.frames.cfade:SetWidth(60)
	self.frames.cfade:SetHeight(40)
	self.frames.cfade:SetTexture("Interface\\ChatFrame\\ChatFrameBackground")
	self.frames.cfade:SetPoint("TOP", self.frames.anchor, "TOP", 0, -4)
	self.frames.cfade:SetBlendMode("ADD")
	self.frames.cfade:SetGradientAlpha("VERTICAL", .1, .1, .1, 0, .25, .25, .25, 1)
	self.frames.anchor.Fade = self.frames.fade

	self.frames.rightbutton = CreateFrame("Button", nil, self.frames.anchor)
	self.frames.rightbutton.owner = self
	self.frames.rightbutton:SetWidth(40)
	self.frames.rightbutton:SetHeight(25)
	self.frames.rightbutton:SetPoint("CENTER", self.frames.anchor, "CENTER")
	self.frames.rightbutton:SetScript( "OnClick", function() self.frames.anchor:Hide() end )

	t = self.frames.rightbutton:CreateTexture()
	t:SetWidth(50)
	t:SetHeight(32)
	t:SetPoint("CENTER", self.frames.rightbutton, "CENTER")
	t:SetTexture("Interface\\Buttons\\UI-Panel-Button-Up")
	t:SetTexCoord(0, 0.625, 0, 0.6875)
	self.frames.rightbutton:SetNormalTexture(t)

	t = self.frames.rightbutton:CreateTexture(nil, "BACKGROUND")
	t:SetTexture("Interface\\Buttons\\UI-Panel-Button-Down")
	t:SetTexCoord(0, 0.625, 0, 0.6875)
	t:SetAllPoints(self.frames.rightbutton)
	self.frames.rightbutton:SetPushedTexture(t)

	t = self.frames.rightbutton:CreateTexture()
	t:SetTexture("Interface\\Buttons\\UI-Panel-Button-Highlight")
	t:SetTexCoord(0, 0.625, 0, 0.6875)
	t:SetAllPoints(self.frames.rightbutton)
	t:SetBlendMode("ADD")
	self.frames.rightbutton:SetHighlightTexture(t)
	self.frames.rightbuttontext = self.frames.rightbutton:CreateFontString(nil,"OVERLAY")
	self.frames.rightbuttontext:SetFontObject(GameFontHighlight)
	self.frames.rightbuttontext:SetText("Hide")
	self.frames.rightbuttontext:SetAllPoints(self.frames.rightbutton)

	self:RestorePosition()
end

function Assister_MoveTooltip:SavePosition()
	local f = self.frames.anchor
	local s = f:GetEffectiveScale()

	settingsMoveTooltip.profile.posx = f:GetLeft() * s
	settingsMoveTooltip.profile.posy = f:GetTop() * s
end

function Assister_MoveTooltip:RestorePosition()
	local x = settingsMoveTooltip.profile.posx
	local y = settingsMoveTooltip.profile.posy

	if not x or not y then return end

	local f = self.frames.anchor
	local s = f:GetEffectiveScale()

	f:ClearAllPoints()
	f:SetPoint("TOPLEFT", UIParent, "BOTTOMLEFT", x / s, y / s)
end 

--Move tooltip function
function Assister_MoveTooltip:Move()
	function MT_GT_SetDefaultAnchor(tooltip, parent) 
		if ( tooltip == GameTooltip) then
			if settingsMoveTooltip.profile.on == true then
				tooltip:SetOwner(parent, "ANCHOR_NONE");
				tooltip:ClearAllPoints();
				tooltip:SetPoint("TOP", self.frames.anchor, "TOP")
			else
				tooltip:SetOwner(parent, "ANCHOR_NONE");
				tooltip:ClearAllPoints();
				tooltip:SetPoint("BOTTOMRIGHT", "UIParent", "BOTTOMRIGHT", -CONTAINER_OFFSET_X - 13, CONTAINER_OFFSET_Y);
			end
		end
	end
	GameTooltip_SetDefaultAnchor = MT_GT_SetDefaultAnchor;
end